@@ -7,7 +7,7 @@ __AUTHOR__ = 'ugursogukpinar'
 from arguments import Arguments
 from VHCreator import VHCreator
 
-def __main__():
+def main():
     __Arguments = Arguments()
     args = __Arguments.getArgs()
 
@@ -18,5 +18,5 @@ def __main__():
         __VHCreator.addHostName(args.servername)
 
 if __name__ == "__main__":
-    __main__()
+    main()
 
